"use strict";(self.webpackChunk_anaconda_assistant=self.webpackChunk_anaconda_assistant||[]).push([[568],{1568:(a,t,e)=>{e.r(t),e.d(t,{default:()=>r});var n=e(4072),o=e(1464),s=e(6947),i=e(9369);const c=new(e(2111).AssistantPlugin),r={id:"@anaconda/assistant:plugin",description:"A JupyterLab extension.",autoStart:!0,requires:[i.tokens.CoreToken,s.INotebookTracker,o.ICommandPalette],optional:[n.ILabShell],activate:(a,t,e,n,o)=>{const{corePlugin:s}=t,i=!o;c.activate(a,{corePlugin:s,notebookTracker:e,palette:n,isJupyterNotebook:i}),console.log("JupyterLab extension @anaconda/assistant is activated!")}}}}]);